==> gameap-3.1-shared.zip: upload/resources/lang/ru/labels.php <==
<?php

return [
    // Main
    'name' => 'Имя',
    'the_value' => 'Значение',

    // ClientCertificates
    'private_key_pass' => 'Пароль от приватного ключа',

    // DedicatedServer
    'enabled' => 'Включен',
    'os' => 'Операционная система',
    'location' => 'Локация',
    'provider' => 'Провайдер',
    'ip' => 'IP',
    'ram' => 'RAM',
    'cpu' => 'CPU',
    'work_path' => 'Рабочий каталог',
    'steamcmd_path' => 'Путь к SteamCMD',
    'gdaemon_host' => 'GDaemon хост',
    'gdaemon_port' => 'GDaemon порт',
    'gdaemon_api_key' => 'GDaemon API ключ',
    'gdaemon_api_token' => 'GDaemon API токен',
    'gdaemon_login' => 'GDaemon логин',
    'gdaemon_password' => 'GDaemon пароль',
    'gdaemon_server_cert' => 'GDaemon сертификат сервера',
    'client_certificate_id' => 'GDaemon сертификат клиента',
    'prefer_install_method' => 'Предпочитаемый способ установки сервера',
    'script_install' => 'Скрипт установки',
    'script_reinstall' => 'Скрипт переустановки',
    'script_update' => 'Скрипт обновления',
    'script_start' => 'Скрипт запуска',
    'script_pause' => 'Скрипт паузы',
    'script_unpause' => 'Скрипт возобновления',
    'script_stop' => 'Скрипт остановки',
    'script_restart' => 'Скрипт перезагрузки',
    'script_status' => 'Скрипт статуса',
    'script_stats' => 'Скрипт статистики',
    'script_get_console' => 'Скрипт получения консоли',
    'script_send_command' => 'Скрипт отправки команды',
    'script_delete' => 'Скрипт удаления',

    // Game
    'code' => 'Код',
    'start_code' => 'Старт код',
    'engine' => 'Движок',
    'engine_version' => 'Версия движка',
    'steam_app_id_linux' => 'Steam App ID (Linux)',
    'steam_app_id_windows' => 'Steam App ID (Windows)',
    'steam_app_set_config' => 'Steam App Set Config',

    // GameMod
    'game_code' => 'Код игры',
    'fast_rcon' => 'Fast RCON',
    'vars' => 'Переменные',
    'remote_repository_linux' => 'Удалённый репозиторий (Linux)',
    'remote_repository_windows' => 'Удалённый репозиторий (Windows)',
    'local_repository_linux' => 'Локальный репозиторий (Linux)',
    'local_repository_windows' => 'Локальный репозиторий (Windows)',
    'kick_cmd' => 'Команда кика',
    'ban_cmd' => 'Команда бана',
    'chname_cmd' => 'Команда смены имени (ника)',
    'srestart_cmd' => 'Команда перезапуска',
    'chmap_cmd' => 'Команда смены карты',
    'sendmsg_cmd' => 'Команда отправки сообщения',
    'passwd_cmd' => 'Команда установки/смены пароля',
    'start_cmd_linux' => 'Команда запуска (Linux)',
    'start_cmd_windows' => 'Команда запуска (Windows)',

    // Server
    'game_server' => 'Игровой сервер',
    'installed' => 'Установлен',
    'blocked' => 'Заблокирован',
    'uuid' => 'UUID',
    'uuid_short' => 'Короткий UUID',
    'ds_id' => 'Выделенный сервер',
    'game_id' => 'Игра',
    'game_mod_id' => 'Модификация',
    'expires' => 'Истекает',
    'server_port' => 'Порт сервера',
    'query_port' => 'Query порт',
    'rcon_port' => 'RCON порт',

    // TODO: Replace to rcon_password
    'rcon' => 'RCON пароль',
    'dir' => 'Каталог',
    'su_user' => 'Имя пользователя на выделенном сервере',
    'cpu_limit' => 'Лимит CPU',
    'ram_limit' => 'Лимит RAM',
    'net_limit' => 'Лимит NET',
    'start_command' => 'Команда запуска',
    'stop_command' => 'Команда остановки',
    'force_stop_command' => 'Команда быстрой остановки',
    'restart_command' => 'Команда перезагрузки',

    // User
    'login' => 'Логин',
    'current_password' => 'Текущий пароль',
    'password' => 'Пароль',
    'password_confirmation' => 'Подтверждение пароля',
    'roles' => 'Роли',
    'token_name' => 'Имя токена',

    // Generic servers
    'host' => 'Хост',
    'port' => 'Порт',
    'username' => 'Имя пользователя',

    //
    'description' => 'Описание',
    'summary' => 'Краткое описание',
];

==> gameap-3.2-shared.zip: upload/resources/lang/ru/labels.php <==
<?php

return [
    // Main
    'name' => 'Имя',
    'the_value' => 'Значение',

    // ClientCertificates
    'private_key_pass' => 'Пароль от приватного ключа',

    // DedicatedServer
    'enabled' => 'Включен',
    'os' => 'Операционная система',
    'location' => 'Локация',
    'provider' => 'Провайдер',
    'ip' => 'IP',
    'ram' => 'RAM',
    'cpu' => 'CPU',
    'work_path' => 'Рабочий каталог',
    'steamcmd_path' => 'Путь к SteamCMD',
    'gdaemon_host' => 'GDaemon хост',
    'gdaemon_port' => 'GDaemon порт',
    'gdaemon_api_key' => 'GDaemon API ключ',
    'gdaemon_api_token' => 'GDaemon API токен',
    'gdaemon_login' => 'GDaemon логин',
    'gdaemon_password' => 'GDaemon пароль',
    'gdaemon_server_cert' => 'GDaemon сертификат сервера',
    'client_certificate_id' => 'GDaemon сертификат клиента',
    'prefer_install_method' => 'Предпочитаемый способ установки сервера',
    'script_install' => 'Скрипт установки',
    'script_reinstall' => 'Скрипт переустановки',
    'script_update' => 'Скрипт обновления',
    'script_start' => 'Скрипт запуска',
    'script_pause' => 'Скрипт паузы',
    'script_unpause' => 'Скрипт возобновления',
    'script_stop' => 'Скрипт остановки',
    'script_kill' => 'Скрипт принудительной остановки',
    'script_restart' => 'Скрипт перезагрузки',
    'script_status' => 'Скрипт статуса',
    'script_stats' => 'Скрипт статистики',
    'script_get_console' => 'Скрипт получения консоли',
    'script_send_command' => 'Скрипт отправки команды',
    'script_delete' => 'Скрипт удаления',

    // Game
    'code' => 'Код',
    'start_code' => 'Старт код',
    'engine' => 'Движок',
    'engine_version' => 'Версия движка',
    'steam_app_id_linux' => 'Steam App ID (Linux)',
    'steam_app_id_windows' => 'Steam App ID (Windows)',
    'steam_app_set_config' => 'Steam App Set Config',

    // GameMod
    'game_code' => 'Код игры',
    'fast_rcon' => 'Fast RCON',
    'vars' => 'Переменные',
    'remote_repository_linux' => 'Удалённый репозиторий (Linux)',
    'remote_repository_windows' => 'Удалённый репозиторий (Windows)',
    'local_repository_linux' => 'Локальный репозиторий (Linux)',
    'local_repository_windows' => 'Локальный репозиторий (Windows)',
    'kick_cmd' => 'Команда кика',
    'ban_cmd' => 'Команда бана',
    'chname_cmd' => 'Команда смены имени (ника)',
    'srestart_cmd' => 'Команда перезапуска',
    'chmap_cmd' => 'Команда смены карты',
    'sendmsg_cmd' => 'Команда отправки сообщения',
    'passwd_cmd' => 'Команда установки/смены пароля',
    'start_cmd_linux' => 'Команда запуска (Linux)',
    'start_cmd_windows' => 'Команда запуска (Windows)',

    // Server
    'game_server' => 'Игровой сервер',
    'installed' => 'Установлен',
    'blocked' => 'Заблокирован',
    'uuid' => 'UUID',
    'uuid_short' => 'Короткий UUID',
    'ds_id' => 'Выделенный сервер',
    'game_id' => 'Игра',
    'game_mod_id' => 'Модификация',
    'expires' => 'Истекает',
    'server_port' => 'Порт сервера',
    'query_port' => 'Query порт',
    'rcon_port' => 'RCON порт',

    // TODO: Replace to rcon_password
    'rcon' => 'RCON пароль',
    'dir' => 'Каталог',
    'su_user' => 'Имя пользователя на выделенном сервере',
    'cpu_limit' => 'Лимит CPU',
    'ram_limit' => 'Лимит RAM',
    'net_limit' => 'Лимит NET',
    'start_command' => 'Команда запуска',
    'stop_command' => 'Команда остановки',
    'force_stop_command' => 'Команда быстрой остановки',
    'restart_command' => 'Команда перезагрузки',

    // User
    'login' => 'Логин',
    'email' => 'Email',
    'current_password' => 'Текущий пароль',
    'new_password' => 'Новый пароль',
    'password' => 'Пароль',
    'password_confirmation' => 'Подтверждение пароля',
    'roles' => 'Роли',
    'token_name' => 'Имя токена',

    // Generic servers
    'host' => 'Хост',
    'port' => 'Порт',
    'username' => 'Имя пользователя',

    //
    'description' => 'Описание',
    'summary' => 'Краткое описание',
];
